from .flow import FlowStore
from .pea import PeaStore
from .pod import PodStore
from .workspace import WorkspaceStore

flow_store = FlowStore()
pea_store = PeaStore()
pod_store = PodStore()
workspace_store = WorkspaceStore()
